summaryrefslogtreecommitdiffstats
path: root/src/replaygain.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/replaygain.h')
-rwxr-xr-xsrc/replaygain.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/src/replaygain.h b/src/replaygain.h
index ff9e38a..568d3a8 100755
--- a/src/replaygain.h
+++ b/src/replaygain.h
@@ -3,8 +3,8 @@
#ifndef REPLAYGAIN_H
#define REPLAYGAIN_H
-#include <qobject.h>
-#include <qstringlist.h>
+#include <tqobject.h>
+#include <tqstringlist.h>
class Config;
class Logger;
@@ -15,9 +15,10 @@ class KProcess;
* @author Daniel Faust <[email protected]>
* @version 0.3
*/
-class ReplayGain : public QObject
+class ReplayGain : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
enum Mode {
calc_track = 0x0001,
@@ -43,12 +44,12 @@ public:
* @param prc a pointer to a KProcess
* @param remove if true the Replay Gain tags are being removed, if false (default) the tags are calculated and added
*/
- bool apply( QStringList files, const QString& format, KProcess* proc, int logID, Mode mode = Mode(calc_track|calc_album) ); // NOTE const QStringList& ?
+ bool apply( TQStringList files, const TQString& format, KProcess* proc, int logID, Mode mode = Mode(calc_track|calc_album) ); // NOTE const TQStringList& ?
/*
* Returns the track and the album gain (in this order) of the @p file
*/
//static QValueList<float> getReplayGain( QString file ); // obsolete
private:
Config* config;
@@ -43,12 +44,12 @@ public:
* Returns the track and the album gain (in this order) of the @p file
*/
- //static QValueList<float> getReplayGain( QString file ); // obsolete
+ //static TQValueList<float> getReplayGain( TQString file ); // obsolete
private:
Config* config;